OC.L10N.register(
    "files_texteditor",
    {
    "This file is too big to be opened. Please download the file instead." : "Фајл је превелик за отварање. Преузмите га уместо отварања.",
    "Cannot read the file." : "Не могу да очитам фајл.",
    "Invalid file path supplied." : "Дата је неисправна путања фајла.",
    "Cannot save file as it has been modified since opening" : "Не могу да сачувам фајл јер је измењен откако је отворен",
    "Insufficient permissions" : "Недовољне дозволе",
    "File path not supplied" : "Није добијена путања фајла",
    "File mtime not supplied" : "Није добијено време измене фајла",
    "saving..." : "уписујем...",
    "saved!" : "сачувано!",
    "failed!" : "неуспех!",
    "Saved" : "Сачувано",
    "There was a problem saving your changes. Click to resume editing." : "Десио се проблем приликом уписа ваших измена. Кликните за наставак уређивања.",
    "An error occurred!" : "Дошло је до грешке!",
    "Text file" : "текстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
